intelmq.bots.collectors.mail package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.collectors.mail package

## Submodules

## intelmq.bots.collectors.mail.collector_mail_attach module

In Version 0.9.5 the attachment filename is no longer surrounded by double quotes, see for the discussion: https://github.com/certtools/intelmq/pull/1134 https://github.com/martinrusev/imbox/commit/7c6cc2fb5f7e39c1496d68f3d432eec19517bf8e#diff-1ae09572064c2e7c225de54ad5b49154

Uses the common mail iteration method from the lib file.

`intelmq.bots.collectors.mail.collector_mail_attach.` `BOT`

  alias of `intelmq.bots.collectors.mail.collector_mail_attach.MailAttachCollectorBot`

class `intelmq.bots.collectors.mail.collector_mail_attach.` `MailAttachCollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.bots.collectors.mail.lib.MailCollectorBot`

  `init`()
  `process_message`(uid, message)

    Returns: seen: Mark the message as seen or not

## intelmq.bots.collectors.mail.collector_mail_body module

Uses the common mail iteration method from the lib file.

`intelmq.bots.collectors.mail.collector_mail_body.` `BOT`

  alias of `intelmq.bots.collectors.mail.collector_mail_body.MailBodyCollectorBot`

class `intelmq.bots.collectors.mail.collector_mail_body.` `MailBodyCollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.bots.collectors.mail.lib.MailCollectorBot`

  `init`()
  `process_message`(uid, message)

    Returns: seen: Mark the message as seen or not

## intelmq.bots.collectors.mail.collector_mail_url module

Uses the common mail iteration method from the lib file.

`intelmq.bots.collectors.mail.collector_mail_url.` `BOT`

  alias of `intelmq.bots.collectors.mail.collector_mail_url.MailURLCollectorBot`

class `intelmq.bots.collectors.mail.collector_mail_url.` `MailURLCollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.bots.collectors.mail.lib.MailCollectorBot`

  `init`()
  `process_message`(uid, message)

    Returns: seen: Mark the message as seen or not

## intelmq.bots.collectors.mail.lib module

class `intelmq.bots.collectors.mail.lib.` `MailCollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`

  `connect_mailbox`()
  `init`()
  `process`()
  `process_message`(uid, message) → bool
    Returns

      Mark the message as seen or not

    Return type

      seen

## Module contents